IOP.mathjax = function() {

	var scriptBase = 'http://cdn.mathjax.org/mathjax/1.1-latest/';
	var scriptUrl = scriptBase + 'MathJax.js?config=default';
	var selectedClass = 'selectedMathJaxOption';

	var load = function() {
		$('#mathJaxOn').addClass(selectedClass);
		$('.texImage').hide();
		var script = document.createElement('script');
		script.type = 'text/javascript';
		script.src = scriptUrl;
		var content = 'MathJax.Hub.Config(IOP.mathjax.config);' +
					 'MathJax.Hub.Startup.onload();';
		if (window.opera) {
			script.innerHTML = content;
		} else {
			script.text = content;
		}
		document.getElementsByTagName("body")[0].appendChild(script);
		$('.MathJax').show();
		$('.MathJax_MathML').show();
		$('#mathJaxOff').removeClass(selectedClass);
	};
	
	var enableMathJax = function() {
		if ($.cookie('MathJaxEnabled') != 'true') {
			$.cookie('MathJaxEnabled', 'true', { expires: 3653, path: '/' });
			if (typeof MathJax == 'undefined') {
				load();
			} else {
				$('#mathJaxOn').addClass(selectedClass);
				$('.texImage').hide();
				$('.MathJax').show();
				$('.MathJax_MathML').show();
				$('#mathJaxOff').removeClass(selectedClass);
			}
		}
	}
	
	var disableMathJax = function() {
		if ($.cookie('MathJaxEnabled') == 'true') {
			$.cookie('MathJaxEnabled', null, { path: '/' });
			$('#mathJaxOff').addClass(selectedClass);
			$('.texImage').show();
			$('.MathJax').hide();
			$('.MathJax_MathML').hide();
			$('#mathJaxOn').removeClass(selectedClass);
		}
	}
	
	$(document).ready(function() {
		$('.mathJaxControls').show();
		$('#mathJaxOn').click(enableMathJax);
		$('#mathJaxOff').click(disableMathJax);
		if ($.cookie('MathJaxEnabled') == 'true') {
			load();
		}
	});

	return {
		config : {
			extensions: ["tex2jax.js"],
			jax: ["input/TeX", "output/HTML-CSS"],
			displayAlign: "left",
			"HTML-CSS": {
                scale: 95
			},
			TeX: {
				extensions: ["AMSmath.js", "AMSsymbols.js", "noUndefined.js"],
				Macros: {
					protect: '',
					bit: '',
					fl: '',
					eqalign: '',
					ms: '',
					bs: '',
					ns: '',
					es: '',
					noindent: '',
					dag: '{\\dagger}',
					tilded: '{\\tilde{d}}',
					// Added by KMJ (UI bug CH42)
					bm: '{\\bf}',
					// Added by KMJ
					bi: '{\\bf\\it}',
					// Added by KMJ (with thanks to Graham Douglas)
					openone: '{\\mathbb{1}}',
					// Added by KMJ (UI bug KJ12)
					mathbbm: [ '{\\mathbb{#1}}', 1],
					Tables: '{\\clearpage\\section*{Tables and table captions}',
					Figures: '{\\clearpage\\section*{Figure captions}',
					References: '{\\section*{References}\\par\\refs}',
					e: '{\\mathrm{e}}',
					rme: '{\\mathrm{e}}',
					rmi: '{\\mathrm{i}}',
					rmd: '{\\mathrm{d}}',
					qquad: '{\\hspace{25pt}}',
					tdot: [ '{\\stackrel{\\dots}{#1}}', 1],
					tqs: '{\\hspace{25pt}}',
					// Disabled by KMJ (UI bug CH5b)
					// fl: '{\\hspace{-6pc}}',
					Tr: '{\\mathop{\\mathrm{Tr}}\\nolimits}',
					tr: '{\\mathop{\\mathrm{tr}}\\nolimits}',
					Or: '{\\mathord{\\mathrm{O}}}',
					lshad: '{[\\![}',
					rshad: '{]\\!]}',
					'case': [ '{{\\textstyle\\frac{#1}{#2}}}', 2],
					dsty: '{\\displaystyle}',
					tsty: '{\\textstyle}',
					ssty: '{\\scriptstyle}',
					sssty: '{\\scriptscriptstyle}',
					opencircle: '{\\mbox{\\Large$\\circ\\,$}}',
					opensquare: '{\\mbox{$\\rlap{$\\sqcap$}\\sqcup$}}',
					opentriangle: '{\\mbox{$\\triangle$}}',
					opentriangledown: '{\\mbox{$\\bigtriangledown$}}',
					opendiamond: '{\\mbox{$\\diamondsuit$}}',
					fullcircle: '{\\mbox{{\\Large$\\bullet\\,$}}}',
					fullsquare: '{\\,\\vrule height5pt depth0pt width5pt}',
					dotted: '{\\protect\\mbox{${\\mathinner{\\cdotp\\cdotp\\cdotp\\cdotp\\cdotp\\cdotp}}$}}',
					dashed: '{\\protect\\mbox{-\\; -\\; -\\; -}}',
					broken: '{\\protect\\mbox{-- -- --}}',
					longbroken: '{\\protect\\mbox{--- --- ---}}',
					chain: '{\\protect\\mbox{--- $\\cdot$ ---}}',
					dashddot: '{\\protect\\mbox{--- $\\cdot$ $\\cdot$ ---}}',
					full: '{\\protect\\mbox{------}}',
					boldarrayrulewidth: '{1\\p@} ',
					br: '{\\ms\\bhline\\ms}',
					mr: '{\\ms\\hline\\ms}',
					// Disabled by KMJ (\\noalign does not work)
					// ms: '{\\noalign{\\vspace{3\\p@ plus2\\p@ minus1\\p@}}}',
					// bs: '{\\noalign{\\vspace{6\\p@ plus2\\p@ minus2\\p@}}}',
					// ns: '{\\noalign{\\vspace{-3\\p@ plus-1\\p@ minus-1\\p@}}}',
					// es: '{\\noalign{\\vspace{6\\p@ plus2\\p@ minus2\\p@}}\\displaystyle}',
					etal: '{{\\it et al\\/}\\ }',
					dash: '{------}',
					nonum: '{\\par\\item[]}',
					CQG: '{{\\it Class. Quantum Grav.} }',
					CTM: '{{\\it Combust. Theory Modelling\\/} }',
					DSE: '{{\\it Distrib. Syst. Engng.\\/} }',
					EJP: '{{\\it Eur. J. Phys.} } ',
					JNE: '{{\\it J. Neural Eng.} }',
					PB: '{{\\it Phys. Biol.} }',
					SMS: '{{\\it Smart Mater. Struct.} }',
					HPP: '{{\\it High Perform. Polym.} }',
					IP: '{{\\it Inverse Problems\\/} }',
					JHM: '{{\\it J. Hard Mater.} }',
					JO: '{{\\it J. Opt.} }',
					JOA: '{{\\it J. Opt. A: Pure Appl. Opt.} }',
					JOB: '{{\\it J. Opt. B: Quantum Semiclass. Opt.} }',
					JPA: '{{\\it J. Phys. A: Math. Gen.} }',
					JPB: '{{\\it J. Phys. B: At. Mol. Phys.} }',
					jpb: '{{\\it J. Phys. B: At. Mol. Opt. Phys.} }',
					JPC: '{{\\it J. Phys. C: Solid State Phys.} }',
					JPCM: '{{\\it J. Phys.: Condens. Matter\\/} }',
					JPD: '{{\\it J. Phys. D: Appl. Phys.} }',
					JPE: '{{\\it J. Phys. E: Sci. Instrum.} }',
					JPF: '{{\\it J. Phys. F: Met. Phys.} }',
					JPG: '{{\\it J. Phys. G: Nucl. Phys.} }',
					jpg: '{{\\it J. Phys. G: Nucl. Part. Phys.} }',
					JMM: '{{\\it J. Micromech. Microeng.\\/} }',
					MSMSE: '{{\\it Modelling Simulation Mater. Sci. Eng.} }',
					MST: '{{\\it Meas. Sci. Technol.} }',
					NET: '{{\\it Network: Comput. Neural Syst.} }',
					NJP: '{{\\it New J. Phys.} }',
					NL: '{{\\it Nonlinearity\\/} }',
					NT: '{{\\it Nanotechnology} }',
					PAO: '{{\\it Pure Appl. Optics\\/} }',
					PM: '{{\\it Physiol. Meas.} }',
					PMB: '{{\\it Phys. Med. Biol.} }',
					PPCF: '{{\\it Plasma Phys. Control. Fusion\\/} }',
					PSST: '{{\\it Plasma Sources Sci. Technol.} }',
					PUS: '{{\\it Public Understand. Sci.} }',
					QO: '{{\\it Quantum Opt.} }',
					QSO: '{{\\em Quantum Semiclass. Opt.} }',
					RPP: '{{\\it Rep. Prog. Phys.} }',
					SLC: '{{\\it Sov. Lightwave Commun.} }',
					SST: '{{\\it Semicond. Sci. Technol.} }',
					SUST: '{{\\it Supercond. Sci. Technol.} }',
					WRM: '{{\\it Waves Random Media\\/} }',
					AC: '{{\\it Acta Crystallogr.} }',
					AM: '{{\\it Acta Metall.} }',
					AP: '{{\\it Ann. Phys., Lpz.} }',
					APNY: '{{\\it Ann. Phys., NY\\/} }',
					APP: '{{\\it Ann. Phys., Paris\\/} }',
					CJP: '{{\\it Can. J. Phys.} }',
					JAP: '{{\\it J. Appl. Phys.} }',
					JCP: '{{\\it J. Chem. Phys.} }',
					JJAP: '{{\\it Japan. J. Appl. Phys.} }',
					JP: '{{\\it J. Physique\\/} }',
					JPhCh: '{{\\it J. Phys. Chem.} }',
					JMMM: '{{\\it J. Magn. Magn. Mater.} }',
					JMP: '{{\\it J. Math. Phys.} }',
					JOSA: '{{\\it J. Opt. Soc. Am.} }',
					JPSJ: '{{\\it J. Phys. Soc. Japan\\/} }',
					JQSRT: '{{\\it J. Quant. Spectrosc. Radiat. Transfer\\/} }',
					NC: '{{\\it Nuovo Cimento\\/} }',
					NIM: '{{\\it Nucl. Instrum. Methods\\/} }',
					NP: '{{\\it Nucl. Phys.} }',
					PL: '{{\\it Phys. Lett.} }',
					PR: '{{\\it Phys. Rev.} }',
					PRL: '{{\\it Phys. Rev. Lett.} }',
					PRS: '{{\\it Proc. R. Soc.} }',
					PS: '{{\\it Phys. Scr.} }',
					PSS: '{{\\it Phys. Status Solidi\\/} }',
					PTRS: '{{\\it Phil. Trans. R. Soc.} }',
					RMP: '{{\\it Rev. Mod. Phys.} }',
					RSI: '{{\\it Rev. Sci. Instrum.} }',
					SSC: '{{\\it Solid State Commun.} }',
					ZP: '{{\\it Z. Phys.} }'
				}
			}
		}
	};
	
}();

